#
# spec file for package fastjet-contrib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib libfastjetcontribfragile
Name:           fastjet-contrib
Version:        1.054
Release:        1.3
Summary:        A library of 3rd-party add-ons to FastJet
License:        GPL-2.0-only
URL:            https://fastjet.hepforge.org/contrib/
Source:         https://fastjet.hepforge.org/contrib/downloads/fjcontrib-%{version}.tar.gz
# PATCH-FIX-UPSTREAM - https://github.com/alisw/fastjet/pull/6
BuildRequires:  fastjet-devel
BuildRequires:  gcc-c++

%description
%{name} provides a library of 3rd-party add-ons to FastJet.

%package -n %{shlib}
Summary:        Shared library for fastjet-contrib

%description -n %{shlib}
This package provides the shared library for fastjet-contrib.

%package devel
Summary:        Headers for fastjet-contrib
Requires:       %{shlib} = %{version}

%description devel
This package provides the headers for writing code using fastjet-contrib.

%package devel-static
Summary:        Static libraries and headers for fastjet-contrib
Requires:       %{name}-devel = %{version}

%description devel-static
This package provides the static libraries for fastjet-contrib to link against.

%prep
%autosetup -p1 -n fjcontrib-%{version}

%build
# %%configure does not work as a few of the args passed to it isn't recognised by the configure script
./configure --fastjet-config=%{_bindir}/fastjet-config --prefix=%{buildroot}%{_prefix}
# Examples are used by make check
%make_build examples
%make_build fragile-shared

%install
%make_install
make fragile-shared-install

# Thanks to definciencies in configure script, need to move the libraries to the correct loc manually
mkdir -p %{buildroot}%{_libdir}
%if "%{_lib}" != "lib"
mv %{buildroot}%{_prefix}/lib/* %{buildroot}%{_libdir}/
%endif

%check
%make_build check

%files -n %{shlib}
%{_libdir}/*.so

%files devel-static
%{_libdir}/*.a

%files devel
%doc AUTHORS ChangeLog README NEWS
%license COPYING
%{_includedir}/fastjet/contrib/

%changelog
* Tue Dec 17 2024 ming li <mli@suse.com>
- update to 1.054:
  * addition of new SignalFreeBackgroundEstimator contrib,
    version 1.0.0 (see https://arxiv.org/abs/2304.08383)
  * LundPlane updated to version 2.1.1, with bug fixes for
    delta psibar calculations in opposite hemispheres and for
    compilation issues on some systems
  * Nsubjettiness updated to 2.3.2 with change in recommended axes
    away from OnePass, and addition of HalfKT axes options
    recommended for beta = 2.
    This release also fixes a few compiler warnings.
  * ConstituentSubtractor updated to version 1.4.7, which resolves
    rounding-error induced failures of make check on Mac M2 systems
  * RecursiveTools updated to 2.0.2, addressing rounding-error
    induced make check issues on Mac M2 systems
  * EnergyCorrelator updated to 1.3.2, addressing rounding-error
    induced make check issues on Mac M2 systems
  * configure script now sorts contribs alphabetically to ensure
    reproducibility of build order (thanks to Stefan Bruns)
  * make check now correctly gives a non-zero return code if any of
    the underlying contribs fail their tests
- Remove reproducible.patch, this issue has been fixed in the new version
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sat Jan  6 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 1.053:
  * update LundPlane to version 2.0.4 with a const-correctness fix
- enable unit tests
* Tue Nov 21 2023 Dirk Müller <dmueller@suse.com>
- update to 1.052:
  * update of ConstituentSubtractor to v1.4.6, which brings small
    bug fixes
  * new KTClusCXX (1.0.1), a C++ re-implementation of the
    interface and features of Mike Seymour's Fortran ktclus package
  * Update of LundPlane to 2.0.3, to fix missing header
    installation
  * updated LundPlane to 2.0.2, fixing compilation issues with
    g++-12
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.049:
  * updated Nsubjettiness to 2.26
* Wed Oct 12 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to sort the file list (boo#1041090)
* Fri Jan  7 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.048:
  * Inclusion of C++11 check files.
- Changes from version 1.047:
  * Adds RecursiveLundEEGenerator for e+e- studies.
* Fri Aug 27 2021 Dirk Stoecker <opensuse@dstoecker.de>
- update to 1.046 with RecursiveTools updated to v2.0.1
  * added rare divide-by-zero in calculation of mu2
* Mon Dec 21 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.045:
  * First release of Centauro (DIS jet algorithm plugin), v 1.0.0.
- Changes from version 1.044:
  * Update of RecursiveTools to 2.0.0.
- Changes from version 1.043:
  * Updates of ConstituentSubtractor to 1.4.5 and LundPlane to
    1.0.3 to fix c++98 compatibility issues.
- Minor specfile cleanups with spec-cleaner.
* Tue Aug 20 2019 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
